352 bld_pip_profiler
####################

API Breaks
----------
- N/A

Features
--------
- N/A

Bugfixes
--------
- N/A

Maintenance
-----------
- Use `line_profiler` in pip dev_requirements instead of `line-profiler` to avoid confusion

Contributors
------------
- tangkong
